diff level1/modules/co80.asm @ 1933:1e312b144f4d

Major changes: CCIO,CC3IO are now VTIO GrfInt is now CoGrf WindInt is now CoWin VDGInt (L2), CO32 (L1) is now CoVDG CO51 (L1) is now CoHR CO80 (L1) is now CoWP All files referencing these have been changed
author boisy
date Sat, 26 Nov 2005 21:31:29 +0000
parents afae4d350682
children 6e40b043d3e0
line wrap: on
line diff
--- a/level1/modules/co80.asm	Sat Nov 26 19:51:50 2005 +0000
+++ b/level1/modules/co80.asm	Sat Nov 26 21:31:29 2005 +0000
@@ -1,5 +1,5 @@
 ********************************************************************
 * CO80 - Mysterious 80 column co-driver for CCIO
 *
 * $Id$
 *
@@ -16,13 +16,13 @@
 * recoded dispatch table fcbs
 
          nam   CO80
-         ttl   Mysterious 80 column co-driver for CCIO
+         ttl   Mysterious 80 column co-driver for VTIO
 
 BASEADDR equ   $FF78
 
          ifp1
          use   defsfile
-         use   cciodefs
+         use   vtiodefs
          endc
 
 tylg     set   Systm+Objct   
@@ -138,7 +138,7 @@
          fdb   ErEOL-FuncTbl	$04:ERASE TO EOL
          fdb   CurOnOff-FuncTbl	$05:CURSOR ON/OFF
          fdb   CurRgt-FuncTbl	$06:CURSOR RIGHT
-         fdb   NoOp-FuncTbl	$07:no-op (bel:handled in CCIO)
+         fdb   NoOp-FuncTbl	$07:no-op (bel:handled in VTIO)
          fdb   CurLft-FuncTbl	$08:CURSOR LEFT
          fdb   CurUp-FuncTbl	$09:CURSOR UP
          fdb   CurDown-FuncTbl	$0A:CURSOR DOWN
@@ -1,5 +1,5 @@
 ********************************************************************
-* CO80 - Mysterious 80 column co-driver for CCIO
+* CO80 - Mysterious 80 Column Co-Driver for VTIO
 *
 * $Id$